# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: session_status.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14session_status.proto\x12\"armonik.api.grpc.v1.session_status*i\n\rSessionStatus\x12\x1e\n\x1aSESSION_STATUS_UNSPECIFIED\x10\x00\x12\x1a\n\x16SESSION_STATUS_RUNNING\x10\x01\x12\x1c\n\x18SESSION_STATUS_CANCELLED\x10\x02\x42\x16\xaa\x02\x13\x41rmoniK.Api.gRPC.V1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'session_status_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\023ArmoniK.Api.gRPC.V1'
  _SESSIONSTATUS._serialized_start=60
  _SESSIONSTATUS._serialized_end=165
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: results_common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import result_status_pb2 as result__status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14results_common.proto\x12\x1b\x61rmonik.api.grpc.v1.results\x1a\x13result_status.proto\"\x99\x01\n\tResultRaw\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x15\n\rowner_task_id\x18\x03 \x01(\t\x12?\n\x06status\x18\x04 \x01(\x0e\x32/.armonik.api.grpc.v1.result_status.ResultStatus\x12\x12\n\ncreated_at\x18\x05 \x01(\t\"\xc9\x06\n\x12ListResultsRequest\x12\x0c\n\x04page\x18\x01 \x01(\x05\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x46\n\x06\x66ilter\x18\x03 \x01(\x0b\x32\x36.armonik.api.grpc.v1.results.ListResultsRequest.Filter\x12\x42\n\x04sort\x18\x04 \x01(\x0b\x32\x34.armonik.api.grpc.v1.results.ListResultsRequest.Sort\x1a\xb1\x01\n\x06\x46ilter\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x15\n\rowner_task_id\x18\x03 \x01(\t\x12?\n\x06status\x18\x04 \x01(\x0e\x32/.armonik.api.grpc.v1.result_status.ResultStatus\x12\x15\n\rcreated_after\x18\x05 \x01(\t\x12\x16\n\x0e\x63reated_before\x18\x06 \x01(\t\x1a\xa6\x01\n\x04Sort\x12K\n\x05\x66ield\x18\x01 \x01(\x0e\x32<.armonik.api.grpc.v1.results.ListResultsRequest.OrderByField\x12Q\n\tdirection\x18\x02 \x01(\x0e\x32>.armonik.api.grpc.v1.results.ListResultsRequest.OrderDirection\"\xc2\x01\n\x0cOrderByField\x12\x1e\n\x1aORDER_BY_FIELD_UNSPECIFIED\x10\x00\x12\x1d\n\x19ORDER_BY_FIELD_SESSION_ID\x10\x01\x12\x17\n\x13ORDER_BY_FIELD_NAME\x10\x02\x12 \n\x1cORDER_BY_FIELD_OWNER_TASK_ID\x10\x03\x12\x19\n\x15ORDER_BY_FIELD_STATUS\x10\x04\x12\x1d\n\x19ORDER_BY_FIELD_CREATED_AT\x10\x05\"d\n\x0eOrderDirection\x12\x1f\n\x1bORDER_DIRECTION_UNSPECIFIED\x10\x00\x12\x17\n\x13ORDER_DIRECTION_ASC\x10\x01\x12\x18\n\x14ORDER_DIRECTION_DESC\x10\x02\"~\n\x13ListResultsResponse\x12\x37\n\x07results\x18\x01 \x03(\x0b\x32&.armonik.api.grpc.v1.results.ResultRaw\x12\x0c\n\x04page\x18\x02 \x01(\x05\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\r\n\x05total\x18\x04 \x01(\x05\">\n\x15GetOwnerTaskIdRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x11\n\tresult_id\x18\x02 \x03(\t\"\xb9\x01\n\x16GetOwnerTaskIdResponse\x12V\n\x0bresult_task\x18\x01 \x03(\x0b\x32\x41.armonik.api.grpc.v1.results.GetOwnerTaskIdResponse.MapResultTask\x12\x12\n\nsession_id\x18\x02 \x01(\t\x1a\x33\n\rMapResultTask\x12\x11\n\tresult_id\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\tB\x1e\xaa\x02\x1b\x41rmoniK.Api.gRPC.V1.Resultsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'results_common_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\033ArmoniK.Api.gRPC.V1.Results'
  _RESULTRAW._serialized_start=75
  _RESULTRAW._serialized_end=228
  _LISTRESULTSREQUEST._serialized_start=231
  _LISTRESULTSREQUEST._serialized_end=1072
  _LISTRESULTSREQUEST_FILTER._serialized_start=427
  _LISTRESULTSREQUEST_FILTER._serialized_end=604
  _LISTRESULTSREQUEST_SORT._serialized_start=607
  _LISTRESULTSREQUEST_SORT._serialized_end=773
  _LISTRESULTSREQUEST_ORDERBYFIELD._serialized_start=776
  _LISTRESULTSREQUEST_ORDERBYFIELD._serialized_end=970
  _LISTRESULTSREQUEST_ORDERDIRECTION._serialized_start=972
  _LISTRESULTSREQUEST_ORDERDIRECTION._serialized_end=1072
  _LISTRESULTSRESPONSE._serialized_start=1074
  _LISTRESULTSRESPONSE._serialized_end=1200
  _GETOWNERTASKIDREQUEST._serialized_start=1202
  _GETOWNERTASKIDREQUEST._serialized_end=1264
  _GETOWNERTASKIDRESPONSE._serialized_start=1267
  _GETOWNERTASKIDRESPONSE._serialized_end=1452
  _GETOWNERTASKIDRESPONSE_MAPRESULTTASK._serialized_start=1401
  _GETOWNERTASKIDRESPONSE_MAPRESULTTASK._serialized_end=1452
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: agent_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..common import agent_common_pb2 as agent__common__pb2
from ..common import objects_pb2 as objects__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x61gent_service.proto\x12\x19\x61rmonik.api.grpc.v1.agent\x1a\x12\x61gent_common.proto\x1a\robjects.proto2\xf1\x03\n\x05\x41gent\x12h\n\nCreateTask\x12,.armonik.api.grpc.v1.agent.CreateTaskRequest\x1a*.armonik.api.grpc.v1.agent.CreateTaskReply(\x01\x12\x61\n\x0fGetResourceData\x12&.armonik.api.grpc.v1.agent.DataRequest\x1a$.armonik.api.grpc.v1.agent.DataReply0\x01\x12_\n\rGetCommonData\x12&.armonik.api.grpc.v1.agent.DataRequest\x1a$.armonik.api.grpc.v1.agent.DataReply0\x01\x12_\n\rGetDirectData\x12&.armonik.api.grpc.v1.agent.DataRequest\x1a$.armonik.api.grpc.v1.agent.DataReply0\x01\x12Y\n\nSendResult\x12!.armonik.api.grpc.v1.agent.Result\x1a&.armonik.api.grpc.v1.agent.ResultReply(\x01\x42\x1c\xaa\x02\x19\x41rmoniK.Api.gRPC.V1.Agentb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'agent_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\031ArmoniK.Api.gRPC.V1.Agent'
  _AGENT._serialized_start=86
  _AGENT._serialized_end=583
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from ..common import sessions_common_pb2 as sessions__common__pb2


class SessionsStub(object):
    """*
    Service for handling sessions.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListSessions = channel.unary_unary(
                '/armonik.api.grpc.v1.sessions.Sessions/ListSessions',
                request_serializer=sessions__common__pb2.ListSessionsRequest.SerializeToString,
                response_deserializer=sessions__common__pb2.ListSessionsResponse.FromString,
                )
        self.GetSession = channel.unary_unary(
                '/armonik.api.grpc.v1.sessions.Sessions/GetSession',
                request_serializer=sessions__common__pb2.GetSessionRequest.SerializeToString,
                response_deserializer=sessions__common__pb2.GetSessionResponse.FromString,
                )
        self.CancelSession = channel.unary_unary(
                '/armonik.api.grpc.v1.sessions.Sessions/CancelSession',
                request_serializer=sessions__common__pb2.CancelSessionRequest.SerializeToString,
                response_deserializer=sessions__common__pb2.CancelSessionResponse.FromString,
                )


class SessionsServicer(object):
    """*
    Service for handling sessions.
    """

    def ListSessions(self, request, context):
        """*
        Get a sessions list using pagination, filters and sorting.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSession(self, request, context):
        """*
        Get a session by its id.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CancelSession(self, request, context):
        """*
        Cancel a session by its id.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SessionsServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListSessions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListSessions,
                    request_deserializer=sessions__common__pb2.ListSessionsRequest.FromString,
                    response_serializer=sessions__common__pb2.ListSessionsResponse.SerializeToString,
            ),
            'GetSession': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSession,
                    request_deserializer=sessions__common__pb2.GetSessionRequest.FromString,
                    response_serializer=sessions__common__pb2.GetSessionResponse.SerializeToString,
            ),
            'CancelSession': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelSession,
                    request_deserializer=sessions__common__pb2.CancelSessionRequest.FromString,
                    response_serializer=sessions__common__pb2.CancelSessionResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'armonik.api.grpc.v1.sessions.Sessions', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Sessions(object):
    """*
    Service for handling sessions.
    """

    @staticmethod
    def ListSessions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/armonik.api.grpc.v1.sessions.Sessions/ListSessions',
            sessions__common__pb2.ListSessionsRequest.SerializeToString,
            sessions__common__pb2.ListSessionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/armonik.api.grpc.v1.sessions.Sessions/GetSession',
            sessions__common__pb2.GetSessionRequest.SerializeToString,
            sessions__common__pb2.GetSessionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CancelSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/armonik.api.grpc.v1.sessions.Sessions/CancelSession',
            sessions__common__pb2.CancelSessionRequest.SerializeToString,
            sessions__common__pb2.CancelSessionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sessions_common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import objects_pb2 as objects__pb2
from . import session_status_pb2 as session__status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15sessions_common.proto\x12\x1c\x61rmonik.api.grpc.v1.sessions\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\robjects.proto\x1a\x14session_status.proto\"\x8f\x02\n\nSessionRaw\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x41\n\x06status\x18\x02 \x01(\x0e\x32\x31.armonik.api.grpc.v1.session_status.SessionStatus\x12\x15\n\rpartition_ids\x18\x03 \x03(\t\x12\x31\n\x07options\x18\x04 \x01(\x0b\x32 .armonik.api.grpc.v1.TaskOptions\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x63\x61ncelled_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xc9\x01\n\x0eSessionSummary\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x41\n\x06status\x18\x02 \x01(\x0e\x32\x31.armonik.api.grpc.v1.session_status.SessionStatus\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x63\x61ncelled_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xef\x07\n\x13ListSessionsRequest\x12\x0c\n\x04page\x18\x01 \x01(\x05\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12H\n\x06\x66ilter\x18\x03 \x01(\x0b\x32\x38.armonik.api.grpc.v1.sessions.ListSessionsRequest.Filter\x12\x44\n\x04sort\x18\x04 \x01(\x0b\x32\x36.armonik.api.grpc.v1.sessions.ListSessionsRequest.Sort\x1a\xe8\x02\n\x06\x46ilter\x12\x18\n\x10\x61pplication_name\x18\x01 \x01(\t\x12\x1b\n\x13\x61pplication_version\x18\x02 \x01(\t\x12\x12\n\nsession_id\x18\x03 \x01(\t\x12\x31\n\rcreated_after\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0e\x63reated_before\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x0f\x63\x61ncelled_after\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10\x63\x61ncelled_before\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x41\n\x06status\x18\x08 \x01(\x0e\x32\x31.armonik.api.grpc.v1.session_status.SessionStatus\x1a\xaa\x01\n\x04Sort\x12M\n\x05\x66ield\x18\x01 \x01(\x0e\x32>.armonik.api.grpc.v1.sessions.ListSessionsRequest.OrderByField\x12S\n\tdirection\x18\x02 \x01(\x0e\x32@.armonik.api.grpc.v1.sessions.ListSessionsRequest.OrderDirection\"\xa8\x01\n\x0cOrderByField\x12\x1e\n\x1aORDER_BY_FIELD_UNSPECIFIED\x10\x00\x12\x1d\n\x19ORDER_BY_FIELD_SESSION_ID\x10\x01\x12\x19\n\x15ORDER_BY_FIELD_STATUS\x10\x02\x12\x1d\n\x19ORDER_BY_FIELD_CREATED_AT\x10\x03\x12\x1f\n\x1bORDER_BY_FIELD_CANCELLED_AT\x10\x04\"d\n\x0eOrderDirection\x12\x1f\n\x1bORDER_DIRECTION_UNSPECIFIED\x10\x00\x12\x17\n\x13ORDER_DIRECTION_ASC\x10\x01\x12\x18\n\x14ORDER_DIRECTION_DESC\x10\x02\"\x86\x01\n\x14ListSessionsResponse\x12>\n\x08sessions\x18\x01 \x03(\x0b\x32,.armonik.api.grpc.v1.sessions.SessionSummary\x12\x0c\n\x04page\x18\x02 \x01(\x05\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\r\n\x05total\x18\x04 \x01(\x05\"\'\n\x11GetSessionRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\"O\n\x12GetSessionResponse\x12\x39\n\x07session\x18\x01 \x01(\x0b\x32(.armonik.api.grpc.v1.sessions.SessionRaw\"*\n\x14\x43\x61ncelSessionRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\"R\n\x15\x43\x61ncelSessionResponse\x12\x39\n\x07session\x18\x01 \x01(\x0b\x32(.armonik.api.grpc.v1.sessions.SessionRawB\x1f\xaa\x02\x1c\x41rmoniK.Api.gRPC.V1.Sessionsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sessions_common_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\034ArmoniK.Api.gRPC.V1.Sessions'
  _SESSIONRAW._serialized_start=126
  _SESSIONRAW._serialized_end=397
  _SESSIONSUMMARY._serialized_start=400
  _SESSIONSUMMARY._serialized_end=601
  _LISTSESSIONSREQUEST._serialized_start=604
  _LISTSESSIONSREQUEST._serialized_end=1611
  _LISTSESSIONSREQUEST_FILTER._serialized_start=805
  _LISTSESSIONSREQUEST_FILTER._serialized_end=1165
  _LISTSESSIONSREQUEST_SORT._serialized_start=1168
  _LISTSESSIONSREQUEST_SORT._serialized_end=1338
  _LISTSESSIONSREQUEST_ORDERBYFIELD._serialized_start=1341
  _LISTSESSIONSREQUEST_ORDERBYFIELD._serialized_end=1509
  _LISTSESSIONSREQUEST_ORDERDIRECTION._serialized_start=1511
  _LISTSESSIONSREQUEST_ORDERDIRECTION._serialized_end=1611
  _LISTSESSIONSRESPONSE._serialized_start=1614
  _LISTSESSIONSRESPONSE._serialized_end=1748
  _GETSESSIONREQUEST._serialized_start=1750
  _GETSESSIONREQUEST._serialized_end=1789
  _GETSESSIONRESPONSE._serialized_start=1791
  _GETSESSIONRESPONSE._serialized_end=1870
  _CANCELSESSIONREQUEST._serialized_start=1872
  _CANCELSESSIONREQUEST._serialized_end=1914
  _CANCELSESSIONRESPONSE._serialized_start=1916
  _CANCELSESSIONRESPONSE._serialized_end=1998
# @@protoc_insertion_point(module_scope)
